"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bitlyApiRequestAllItems = exports.bitlyApiRequest = void 0;
async function bitlyApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const authenticationMethod = this.getNodeParameter('authentication', 0);
    let options = {
        headers: {},
        method,
        qs,
        body,
        uri: uri || `https://api-ssl.bitly.com/v4${resource}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        if (authenticationMethod === 'accessToken') {
            const credentials = this.getCredentials('bitlyApi');
            if (credentials === undefined) {
                throw new Error('No credentials got returned!');
            }
            options.headers = { Authorization: `Bearer ${credentials.accessToken}` };
            return await this.helpers.request(options);
        }
        else {
            return await this.helpers.requestOAuth2.call(this, 'bitlyOAuth2Api', options, { tokenType: 'Bearer' });
        }
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.message) {
            const errorBody = error.response.body;
            throw new Error(`Bitly error response [${error.statusCode}]: ${errorBody.message}`);
        }
        throw error;
    }
}
exports.bitlyApiRequest = bitlyApiRequest;
async function bitlyApiRequestAllItems(propertyName, method, resource, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    query.size = 50;
    do {
        responseData = await bitlyApiRequest.call(this, method, resource, body, query, uri);
        returnData.push.apply(returnData, responseData[propertyName]);
        if (responseData.pagination && responseData.pagination.next) {
            uri = responseData.pagination.next;
        }
    } while (responseData.pagination !== undefined &&
        responseData.pagination.next !== undefined);
    return returnData;
}
exports.bitlyApiRequestAllItems = bitlyApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map