"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calendlyApiRequest = void 0;
async function calendlyApiRequest(method, resource, body = {}, query = {}, uri, option = {}) {
    const credentials = this.getCredentials('calendlyApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const endpoint = 'https://calendly.com/api/v1';
    let options = {
        headers: {
            'Content-Type': 'application/json',
            'X-TOKEN': credentials.apiKey,
        },
        method,
        body,
        qs: query,
        uri: uri || `${endpoint}${resource}`,
        json: true,
    };
    if (!Object.keys(body).length) {
        delete options.form;
    }
    if (!Object.keys(query).length) {
        delete options.qs;
    }
    options = Object.assign({}, options, option);
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.response) {
            const errorMessage = error.response.body.message || error.response.body.description || error.message;
            throw new Error(`Calendly error response [${error.statusCode}]: ${errorMessage}`);
        }
        throw error;
    }
}
exports.calendlyApiRequest = calendlyApiRequest;
//# sourceMappingURL=GenericFunctions.js.map