"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CircleCi = void 0;
const PipelineDescription_1 = require("./PipelineDescription");
const GenericFunctions_1 = require("./GenericFunctions");
class CircleCi {
    constructor() {
        this.description = {
            displayName: 'CircleCI',
            name: 'circleCi',
            icon: 'file:circleCi.png',
            group: ['output'],
            version: 1,
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            description: 'Consume CircleCI API',
            defaults: {
                name: 'CircleCI',
                color: '#04AA51',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'circleCiApi',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    options: [
                        {
                            name: ' Pipeline',
                            value: 'pipeline',
                        },
                    ],
                    default: 'pipeline',
                    description: 'Resource to consume.',
                },
                ...PipelineDescription_1.pipelineOperations,
                ...PipelineDescription_1.pipelineFields,
            ],
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        const length = items.length;
        const qs = {};
        let responseData;
        const resource = this.getNodeParameter('resource', 0);
        const operation = this.getNodeParameter('operation', 0);
        for (let i = 0; i < length; i++) {
            if (resource === 'pipeline') {
                if (operation === 'get') {
                    const vcs = this.getNodeParameter('vcs', i);
                    let slug = this.getNodeParameter('projectSlug', i);
                    const pipelineNumber = this.getNodeParameter('pipelineNumber', i);
                    slug = slug.replace(new RegExp(/\//g), '%2F');
                    const endpoint = `/project/${vcs}/${slug}/pipeline/${pipelineNumber}`;
                    responseData = await GenericFunctions_1.circleciApiRequest.call(this, 'GET', endpoint, {}, qs);
                }
                if (operation === 'getAll') {
                    const vcs = this.getNodeParameter('vcs', i);
                    const filters = this.getNodeParameter('filters', i);
                    const returnAll = this.getNodeParameter('returnAll', i);
                    let slug = this.getNodeParameter('projectSlug', i);
                    slug = slug.replace(new RegExp(/\//g), '%2F');
                    if (filters.branch) {
                        qs.branch = filters.branch;
                    }
                    const endpoint = `/project/${vcs}/${slug}/pipeline`;
                    if (returnAll === true) {
                        responseData = await GenericFunctions_1.circleciApiRequestAllItems.call(this, 'items', 'GET', endpoint, {}, qs);
                    }
                    else {
                        qs.limit = this.getNodeParameter('limit', i);
                        responseData = await GenericFunctions_1.circleciApiRequest.call(this, 'GET', endpoint, {}, qs);
                        responseData = responseData.items;
                        responseData = responseData.splice(0, qs.limit);
                    }
                }
                if (operation === 'trigger') {
                    const vcs = this.getNodeParameter('vcs', i);
                    let slug = this.getNodeParameter('projectSlug', i);
                    const additionalFields = this.getNodeParameter('additionalFields', i);
                    slug = slug.replace(new RegExp(/\//g), '%2F');
                    const endpoint = `/project/${vcs}/${slug}/pipeline`;
                    const body = {};
                    if (additionalFields.branch) {
                        body.branch = additionalFields.branch;
                    }
                    if (additionalFields.tag) {
                        body.tag = additionalFields.tag;
                    }
                    responseData = await GenericFunctions_1.circleciApiRequest.call(this, 'POST', endpoint, body, qs);
                }
            }
            if (Array.isArray(responseData)) {
                returnData.push.apply(returnData, responseData);
            }
            else {
                returnData.push(responseData);
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.CircleCi = CircleCi;
//# sourceMappingURL=CircleCi.node.js.map