"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearbitApiRequest = void 0;
async function clearbitApiRequest(method, api, resource, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('clearbitApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    let options = {
        headers: { Authorization: `Bearer ${credentials.apiKey}` },
        method,
        qs,
        body,
        uri: uri || `https://${api}-stream.clearbit.com${resource}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Clearbit credentials are not valid!');
        }
        if (error.response.body && error.response.body.error && error.response.body.error.message) {
            throw new Error(`Clearbit Error [${error.statusCode}]: ${error.response.body.error.message}`);
        }
        throw new Error('Clearbit Error: ' + error.message);
    }
}
exports.clearbitApiRequest = clearbitApiRequest;
//# sourceMappingURL=GenericFunctions.js.map