"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listFields = exports.listOperations = void 0;
exports.listOperations = [
    {
        displayName: 'Operation',
        name: 'operation',
        type: 'options',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
            },
        },
        options: [
            {
                name: 'Create',
                value: 'create',
                description: 'Create a list',
            },
            {
                name: 'Custom Fields',
                value: 'customFields',
                description: `Retrieve list's custom fields`,
            },
            {
                name: 'Delete',
                value: 'delete',
                description: 'Delete a list',
            },
            {
                name: 'Get',
                value: 'get',
                description: 'Get a list',
            },
            {
                name: 'Get All',
                value: 'getAll',
                description: 'Get all lists',
            },
            {
                name: 'Member',
                value: 'member',
                description: 'Get list members',
            },
            {
                name: 'Update',
                value: 'update',
                description: 'Update a list',
            },
        ],
        default: 'customFields',
        description: 'The operation to perform.',
    },
];
exports.listFields = [
    {
        displayName: 'Team ID',
        name: 'team',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'create',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getTeams',
        },
        required: true,
    },
    {
        displayName: 'Space ID',
        name: 'space',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'create',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getSpaces',
            loadOptionsDependsOn: [
                'team',
            ],
        },
        required: true,
    },
    {
        displayName: 'Folderless List',
        name: 'folderless',
        type: 'boolean',
        default: false,
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'create',
                ],
            },
        },
        required: true,
    },
    {
        displayName: 'Folder ID',
        name: 'folder',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'create',
                ],
                folderless: [
                    false,
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getFolders',
            loadOptionsDependsOn: [
                'space',
            ],
        },
        required: true,
    },
    {
        displayName: 'Name',
        name: 'name',
        type: 'string',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'create',
                ],
            },
        },
        required: true,
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        default: {},
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'create',
                ],
            },
        },
        options: [
            {
                displayName: 'Assignee',
                name: 'assignee',
                type: 'string',
                default: '',
            },
            {
                displayName: 'Content',
                name: 'content',
                type: 'string',
                typeOptions: {
                    alwaysOpenEditWindow: true,
                },
                default: '',
            },
            {
                displayName: 'Due Date',
                name: 'dueDate',
                type: 'dateTime',
                default: '',
            },
            {
                displayName: 'Due Date Time',
                name: 'dueDateTime',
                type: 'boolean',
                default: false,
            },
            {
                displayName: 'Priority',
                name: 'priority',
                type: 'number',
                typeOptions: {
                    minValue: 1,
                    maxValue: 4,
                },
                description: 'Integer mapping as 1 : Urgent, 2 : High, 3 : Normal, 4 : Low',
                default: 3,
            },
            {
                displayName: 'Status',
                name: 'status',
                type: 'options',
                loadOptionsDependsOn: [
                    'list',
                ],
                typeOptions: {
                    loadOptionsMethod: 'getStatuses',
                },
                default: '',
            },
        ],
    },
    {
        displayName: 'List ID',
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'member',
                ],
            },
        },
        description: 'Task ID',
    },
    {
        displayName: 'Return All',
        name: 'returnAll',
        type: 'boolean',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'member',
                ],
            },
        },
        default: true,
        description: 'If all results should be returned or only up to a given limit.',
    },
    {
        displayName: 'Limit',
        name: 'limit',
        type: 'number',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'member',
                ],
                returnAll: [
                    false,
                ],
            },
        },
        typeOptions: {
            minValue: 1,
            maxValue: 100,
        },
        default: 50,
        description: 'How many results to return.',
    },
    {
        displayName: 'Team',
        name: 'team',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'customFields',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getTeams',
        },
        required: true,
    },
    {
        displayName: 'Space',
        name: 'space',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'customFields',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getSpaces',
            loadOptionsDependsOn: [
                'teamId',
            ],
        },
        required: true,
    },
    {
        displayName: 'Folderless List',
        name: 'folderless',
        type: 'boolean',
        default: false,
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'customFields',
                ],
            },
        },
        required: true,
    },
    {
        displayName: 'Folder',
        name: 'folder',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'customFields',
                ],
                folderless: [
                    false,
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getFolders',
            loadOptionsDependsOn: [
                'space',
            ],
        },
        required: true,
    },
    {
        displayName: 'List',
        name: 'list',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'customFields',
                ],
                folderless: [
                    true,
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getFolderlessLists',
            loadOptionsDependsOn: [
                'space',
            ],
        },
        required: true,
    },
    {
        displayName: 'List',
        name: 'list',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'customFields',
                ],
                folderless: [
                    false,
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getLists',
            loadOptionsDependsOn: [
                'folder',
            ],
        },
        required: true,
    },
    {
        displayName: 'Team ID',
        name: 'team',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'delete',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getTeams',
        },
        required: true,
    },
    {
        displayName: 'Space ID',
        name: 'space',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'delete',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getSpaces',
            loadOptionsDependsOn: [
                'team',
            ],
        },
        required: true,
    },
    {
        displayName: 'Folderless List',
        name: 'folderless',
        type: 'boolean',
        default: false,
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'delete',
                ],
            },
        },
        required: true,
    },
    {
        displayName: 'Folder ID',
        name: 'folder',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'delete',
                ],
                folderless: [
                    false,
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getFolders',
            loadOptionsDependsOn: [
                'space',
            ],
        },
        required: true,
    },
    {
        displayName: 'List ID',
        name: 'list',
        type: 'string',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'delete',
                ],
            },
        },
        required: true,
    },
    {
        displayName: 'Team ID',
        name: 'team',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'get',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getTeams',
        },
        required: true,
    },
    {
        displayName: 'Space ID',
        name: 'space',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'get',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getSpaces',
            loadOptionsDependsOn: [
                'team',
            ],
        },
        required: true,
    },
    {
        displayName: 'Folderless List',
        name: 'folderless',
        type: 'boolean',
        default: false,
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'get',
                ],
            },
        },
        required: true,
    },
    {
        displayName: 'Folder ID',
        name: 'folder',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'get',
                ],
                folderless: [
                    false,
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getFolders',
            loadOptionsDependsOn: [
                'space',
            ],
        },
        required: true,
    },
    {
        displayName: 'List ID',
        name: 'list',
        type: 'string',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'get',
                ],
            },
        },
        required: true,
    },
    {
        displayName: 'Team ID',
        name: 'team',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'getAll',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getTeams',
        },
        required: true,
    },
    {
        displayName: 'Space ID',
        name: 'space',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'getAll',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getSpaces',
            loadOptionsDependsOn: [
                'team',
            ],
        },
        required: true,
    },
    {
        displayName: 'Folderless List',
        name: 'folderless',
        type: 'boolean',
        default: false,
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'getAll',
                ],
            },
        },
        required: true,
    },
    {
        displayName: 'Folder ID',
        name: 'folder',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'getAll',
                ],
                folderless: [
                    false,
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getFolders',
            loadOptionsDependsOn: [
                'space',
            ],
        },
        required: true,
    },
    {
        displayName: 'Limit',
        name: 'limit',
        type: 'number',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'getAll',
                ],
            },
        },
        typeOptions: {
            minValue: 1,
            maxValue: 100,
        },
        default: 50,
        description: 'How many results to return.',
    },
    {
        displayName: 'Filters',
        name: 'filters',
        type: 'collection',
        placeholder: 'Add Filter',
        default: {},
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'getAll',
                ],
            },
        },
        options: [
            {
                displayName: 'Archived',
                name: 'archived',
                type: 'boolean',
                default: false,
            },
        ],
    },
    {
        displayName: 'Team ID',
        name: 'team',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'update',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getTeams',
        },
        required: true,
    },
    {
        displayName: 'Space ID',
        name: 'space',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'update',
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getSpaces',
            loadOptionsDependsOn: [
                'team',
            ],
        },
        required: true,
    },
    {
        displayName: 'Folderless List',
        name: 'folderless',
        type: 'boolean',
        default: false,
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'update',
                ],
            },
        },
        required: true,
    },
    {
        displayName: 'Folder ID',
        name: 'folder',
        type: 'options',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'update',
                ],
                folderless: [
                    false,
                ],
            },
        },
        typeOptions: {
            loadOptionsMethod: 'getFolders',
            loadOptionsDependsOn: [
                'space',
            ],
        },
        required: true,
    },
    {
        displayName: 'List ID',
        name: 'list',
        type: 'string',
        default: '',
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'update',
                ],
            },
        },
        required: true,
    },
    {
        displayName: 'Update Fields',
        name: 'updateFields',
        type: 'collection',
        placeholder: 'Add Field',
        default: {},
        displayOptions: {
            show: {
                resource: [
                    'list',
                ],
                operation: [
                    'update',
                ],
            },
        },
        options: [
            {
                displayName: 'Assignee',
                name: 'assignee',
                type: 'options',
                loadOptionsDependsOn: [
                    'list',
                ],
                typeOptions: {
                    loadOptionsMethod: 'getAssignees',
                },
                default: '',
            },
            {
                displayName: 'Content',
                name: 'content',
                type: 'string',
                typeOptions: {
                    alwaysOpenEditWindow: true,
                },
                default: '',
            },
            {
                displayName: 'Due Date',
                name: 'dueDate',
                type: 'dateTime',
                default: '',
            },
            {
                displayName: 'Due Date Time',
                name: 'dueDateTime',
                type: 'boolean',
                default: false,
            },
            {
                displayName: 'Name',
                name: 'name',
                type: 'string',
                default: '',
            },
            {
                displayName: 'Priority',
                name: 'priority',
                type: 'number',
                typeOptions: {
                    minValue: 1,
                    maxValue: 4,
                },
                description: 'Integer mapping as 1 : Urgent, 2 : High, 3 : Normal, 4 : Low',
                default: 3,
            },
            {
                displayName: 'Unset Status',
                name: 'unsetStatus',
                type: 'boolean',
                default: false,
            },
        ],
    },
];
//# sourceMappingURL=ListDescription.js.map