"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clockifyApiRequestAllItems = exports.clockifyApiRequest = void 0;
async function clockifyApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('clockifyApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const BASE_URL = 'https://api.clockify.me/api/v1';
    const options = {
        headers: {
            'Content-Type': 'application/json',
            'X-Api-Key': credentials.apiKey,
        },
        method,
        qs,
        body,
        uri: `${BASE_URL}/${resource}`,
        json: true,
        useQuerystring: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        let errorMessage = error.message;
        if (error.response.body && error.response.body.message) {
            errorMessage = `[${error.statusCode}] ${error.response.body.message}`;
        }
        throw new Error('Clockify Error: ' + errorMessage);
    }
}
exports.clockifyApiRequest = clockifyApiRequest;
async function clockifyApiRequestAllItems(method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query['page-size'] = 50;
    query.page = 1;
    do {
        responseData = await clockifyApiRequest.call(this, method, endpoint, body, query);
        returnData.push.apply(returnData, responseData);
        if (query.limit && (returnData.length >= query.limit)) {
            return returnData;
        }
        query.page++;
    } while (responseData.length !== 0);
    return returnData;
}
exports.clockifyApiRequestAllItems = clockifyApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map