"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.codaApiRequestAllItems = exports.codaApiRequest = void 0;
async function codaApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('codaApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    let options = {
        headers: { 'Authorization': `Bearer ${credentials.accessToken}` },
        method,
        qs,
        body,
        uri: uri || `https://coda.io/apis/v1${resource}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        let errorMessage = error.message;
        if (error.response.body) {
            errorMessage = error.response.body.message || error.response.body.Message || error.message;
        }
        throw new Error('Coda Error: ' + errorMessage);
    }
}
exports.codaApiRequest = codaApiRequest;
async function codaApiRequestAllItems(propertyName, method, resource, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.limit = 100;
    let uri;
    do {
        responseData = await codaApiRequest.call(this, method, resource, body, query, uri);
        uri = responseData.nextPageLink;
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData.nextPageLink !== undefined &&
        responseData.nextPageLink !== '');
    return returnData;
}
exports.codaApiRequestAllItems = codaApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map