"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.disqusApiRequestAllItems = exports.disqusApiRequest = void 0;
async function disqusApiRequest(method, qs = {}, uri, body = {}, option = {}) {
    const credentials = this.getCredentials('disqusApi');
    qs.api_key = credentials.accessToken;
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const queryStringElements = [];
    for (const key of Object.keys(qs)) {
        if (Array.isArray(qs[key])) {
            qs[key].forEach(value => {
                queryStringElements.push(`${key}=${value}`);
            });
        }
        else {
            queryStringElements.push(`${key}=${qs[key]}`);
        }
    }
    let options = {
        method,
        body,
        uri: `https://disqus.com/api/3.0/${uri}?${queryStringElements.join('&')}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        const result = await this.helpers.request(options);
        return result;
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Disqus credentials are not valid!');
        }
        if (error.error && error.error.error_summary) {
            throw new Error(`Disqus error response [${error.statusCode}]: ${error.error.error_summary}`);
        }
        throw error;
    }
}
exports.disqusApiRequest = disqusApiRequest;
async function disqusApiRequestAllItems(method, qs = {}, uri, body = {}, option = {}) {
    const returnData = [];
    let responseData;
    try {
        do {
            responseData = await disqusApiRequest.call(this, method, qs, uri, body, option);
            qs.cursor = responseData.cursor.id;
            returnData.push.apply(returnData, responseData.response);
        } while (responseData.cursor.more === true &&
            responseData.cursor.hasNext === true);
        return returnData;
    }
    catch (error) {
        throw error;
    }
}
exports.disqusApiRequestAllItems = disqusApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map