"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.driftApiRequest = void 0;
async function driftApiRequest(method, resource, body = {}, query = {}, uri, option = {}) {
    let options = {
        headers: {},
        method,
        body,
        qs: query,
        uri: uri || `https://driftapi.com${resource}`,
        json: true,
    };
    if (!Object.keys(body).length) {
        delete options.form;
    }
    if (!Object.keys(query).length) {
        delete options.qs;
    }
    options = Object.assign({}, options, option);
    const authenticationMethod = this.getNodeParameter('authentication', 0);
    try {
        if (authenticationMethod === 'accessToken') {
            const credentials = this.getCredentials('driftApi');
            if (credentials === undefined) {
                throw new Error('No credentials got returned!');
            }
            options.headers['Authorization'] = `Bearer ${credentials.accessToken}`;
            return await this.helpers.request(options);
        }
        else {
            return await this.helpers.requestOAuth2.call(this, 'driftOAuth2Api', options);
        }
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error) {
            const errorMessage = error.response.body.error.message;
            throw new Error(`Drift error response [${error.statusCode}]: ${errorMessage}`);
        }
        throw error;
    }
}
exports.driftApiRequest = driftApiRequest;
//# sourceMappingURL=GenericFunctions.js.map