"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorTrigger = void 0;
class ErrorTrigger {
    constructor() {
        this.description = {
            displayName: 'Error Trigger',
            name: 'errorTrigger',
            icon: 'fa:bug',
            group: ['trigger'],
            version: 1,
            description: 'Triggers the workflow when another workflow has an error',
            maxNodes: 1,
            defaults: {
                name: 'Error Trigger',
                color: '#0000FF',
            },
            inputs: [],
            outputs: ['main'],
            properties: [],
        };
    }
    async execute() {
        const items = this.getInputData();
        const mode = this.getMode();
        if (mode === 'manual' && items.length === 1 && Object.keys(items[0].json).length === 0 && items[0].binary === undefined) {
            const restApiUrl = this.getRestApiUrl();
            const urlParts = restApiUrl.split('/');
            urlParts.pop();
            urlParts.push('execution');
            const id = 231;
            items[0].json = {
                execution: {
                    id,
                    url: `${urlParts.join('/')}/${id}`,
                    retryOf: '34',
                    error: {
                        message: 'Example Error Message',
                        stack: 'Stacktrace',
                    },
                    lastNodeExecuted: 'Node With Error',
                    mode: 'manual',
                },
                workflow: {
                    id: '1',
                    name: 'Example Workflow',
                },
            };
        }
        return this.prepareOutputData(items);
    }
}
exports.ErrorTrigger = ErrorTrigger;
//# sourceMappingURL=ErrorTrigger.node.js.map