"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.eventbriteApiRequestAllItems = exports.eventbriteApiRequest = void 0;
async function eventbriteApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    let options = {
        headers: {},
        method,
        qs,
        body,
        uri: uri || `https://www.eventbriteapi.com/v3${resource}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    const authenticationMethod = this.getNodeParameter('authentication', 0);
    try {
        if (authenticationMethod === 'privateKey') {
            const credentials = this.getCredentials('eventbriteApi');
            if (credentials === undefined) {
                throw new Error('No credentials got returned!');
            }
            options.headers['Authorization'] = `Bearer ${credentials.apiKey}`;
            return await this.helpers.request(options);
        }
        else {
            return await this.helpers.requestOAuth2.call(this, 'eventbriteOAuth2Api', options);
        }
    }
    catch (error) {
        let errorMessage = error.message;
        if (error.response.body && error.response.body.error_description) {
            errorMessage = error.response.body.error_description;
        }
        throw new Error('Eventbrite Error: ' + errorMessage);
    }
}
exports.eventbriteApiRequest = eventbriteApiRequest;
async function eventbriteApiRequestAllItems(propertyName, method, resource, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    do {
        responseData = await eventbriteApiRequest.call(this, method, resource, body, query);
        query.continuation = responseData.pagination.continuation;
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData.pagination !== undefined &&
        responseData.pagination.has_more_items !== undefined &&
        responseData.pagination.has_more_items !== false);
    return returnData;
}
exports.eventbriteApiRequestAllItems = eventbriteApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map