"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.capitalize = exports.validateJSON = exports.freshdeskApiRequestAllItems = exports.freshdeskApiRequest = void 0;
const n8n_core_1 = require("n8n-core");
async function freshdeskApiRequest(method, resource, body = {}, query = {}, uri, option = {}) {
    const credentials = this.getCredentials('freshdeskApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const apiKey = `${credentials.apiKey}:X`;
    const endpoint = 'freshdesk.com/api/v2';
    let options = {
        headers: {
            'Content-Type': 'application/json',
            Authorization: `${Buffer.from(apiKey).toString(n8n_core_1.BINARY_ENCODING)}`,
        },
        method,
        body,
        qs: query,
        uri: uri || `https://${credentials.domain}.${endpoint}${resource}`,
        json: true,
    };
    if (!Object.keys(body).length) {
        delete options.body;
    }
    if (!Object.keys(query).length) {
        delete options.qs;
    }
    options = Object.assign({}, options, option);
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.response) {
            let errorMessage = error.response.body.message || error.response.body.description || error.message;
            if (error.response.body && error.response.body.errors) {
                errorMessage = error.response.body.errors.map((err) => `"${err.field}" => ${err.message}`).join(', ');
            }
            throw new Error(`Freshdesk error response [${error.statusCode}]: ${errorMessage}`);
        }
        throw error;
    }
}
exports.freshdeskApiRequest = freshdeskApiRequest;
async function freshdeskApiRequestAllItems(method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    query.per_page = 100;
    do {
        responseData = await freshdeskApiRequest.call(this, method, endpoint, body, query, uri, { resolveWithFullResponse: true });
        if (responseData.headers.link) {
            uri = responseData.headers['link'].split(';')[0].replace('<', '').replace('>', '');
        }
        returnData.push.apply(returnData, responseData.body);
    } while (responseData.headers['link'] !== undefined &&
        responseData.headers['link'].includes('rel="next"'));
    return returnData;
}
exports.freshdeskApiRequestAllItems = freshdeskApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = [];
    }
    return result;
}
exports.validateJSON = validateJSON;
function capitalize(s) {
    if (typeof s !== 'string')
        return '';
    return s.charAt(0).toUpperCase() + s.slice(1);
}
exports.capitalize = capitalize;
//# sourceMappingURL=GenericFunctions.js.map