"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FunctionItem = void 0;
const { NodeVM } = require('vm2');
class FunctionItem {
    constructor() {
        this.description = {
            displayName: 'Function Item',
            name: 'functionItem',
            icon: 'fa:code',
            group: ['transform'],
            version: 1,
            description: 'Run custom function code which gets executed once per item.',
            defaults: {
                name: 'FunctionItem',
                color: '#ddbb33',
            },
            inputs: ['main'],
            outputs: ['main'],
            properties: [
                {
                    displayName: 'JavaScript Code',
                    name: 'functionCode',
                    typeOptions: {
                        alwaysOpenEditWindow: true,
                        editor: 'code',
                        rows: 10,
                    },
                    type: 'string',
                    default: 'item.myVariable = 1;\nreturn item;',
                    description: 'The JavaScript code to execute for each item.',
                    noDataExpression: true,
                },
            ],
        };
    }
    async executeSingle() {
        let item = this.getInputData();
        item = JSON.parse(JSON.stringify(item));
        const sandbox = {
            getBinaryData: () => {
                return item.binary;
            },
            getNodeParameter: this.getNodeParameter,
            getWorkflowStaticData: this.getWorkflowStaticData,
            helpers: this.helpers,
            item: item.json,
            setBinaryData: (data) => {
                item.binary = data;
            },
        };
        const dataProxy = this.getWorkflowDataProxy();
        Object.assign(sandbox, dataProxy);
        const options = {
            console: 'inherit',
            sandbox,
            require: {
                external: false,
                builtin: [],
            },
        };
        if (process.env.NODE_FUNCTION_ALLOW_BUILTIN) {
            options.require.builtin = process.env.NODE_FUNCTION_ALLOW_BUILTIN.split(',');
        }
        if (process.env.NODE_FUNCTION_ALLOW_EXTERNAL) {
            options.require.external = { modules: process.env.NODE_FUNCTION_ALLOW_EXTERNAL.split(',') };
        }
        const vm = new NodeVM(options);
        const functionCode = this.getNodeParameter('functionCode');
        let jsonData;
        try {
            jsonData = await vm.run(`module.exports = async function() {${functionCode}}()`, __dirname);
        }
        catch (e) {
            return Promise.reject(e);
        }
        if (jsonData === undefined) {
            throw new Error('No data got returned. Always an object has to be returned!');
        }
        const returnItem = {
            json: jsonData,
        };
        if (item.binary) {
            returnItem.binary = item.binary;
        }
        return returnItem;
    }
}
exports.FunctionItem = FunctionItem;
//# sourceMappingURL=FunctionItem.node.js.map