"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getResponseApiRequestAllItems = exports.getresponseApiRequest = void 0;
async function getresponseApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const authentication = this.getNodeParameter('authentication', 0, 'apiKey');
    let options = {
        headers: {
            'Content-Type': 'application/json',
        },
        method,
        body,
        qs,
        uri: uri || `https://api.getresponse.com/v3${resource}`,
        json: true,
    };
    try {
        options = Object.assign({}, options, option);
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        if (authentication === 'apiKey') {
            const credentials = this.getCredentials('getResponseApi');
            options.headers['X-Auth-Token'] = `api-key ${credentials.apiKey}`;
            return await this.helpers.request.call(this, options);
        }
        else {
            return await this.helpers.requestOAuth2.call(this, 'getResponseOAuth2Api', options);
        }
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.message) {
            throw new Error(`GetResponse error response [${error.statusCode}]: ${error.response.body.message}`);
        }
        throw error;
    }
}
exports.getresponseApiRequest = getresponseApiRequest;
async function getResponseApiRequestAllItems(method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.page = 1;
    do {
        responseData = await getresponseApiRequest.call(this, method, endpoint, body, query, undefined, { resolveWithFullResponse: true });
        query.page++;
        returnData.push.apply(returnData, responseData.body);
    } while (responseData.headers.TotalPages !== responseData.headers.CurrentPage);
    return returnData;
}
exports.getResponseApiRequestAllItems = getResponseApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map