"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.gitlabApiRequest = void 0;
async function gitlabApiRequest(method, endpoint, body, query) {
    const options = {
        method,
        headers: {},
        body,
        qs: query,
        uri: '',
        json: true,
    };
    if (query === undefined) {
        delete options.qs;
    }
    const authenticationMethod = this.getNodeParameter('authentication', 0);
    try {
        if (authenticationMethod === 'accessToken') {
            const credentials = this.getCredentials('gitlabApi');
            if (credentials === undefined) {
                throw new Error('No credentials got returned!');
            }
            options.headers['Private-Token'] = `${credentials.accessToken}`;
            options.uri = `${credentials.server.replace(/\/$/, '')}/api/v4${endpoint}`;
            return await this.helpers.request(options);
        }
        else {
            const credentials = this.getCredentials('gitlabOAuth2Api');
            if (credentials === undefined) {
                throw new Error('No credentials got returned!');
            }
            options.uri = `${credentials.server.replace(/\/$/, '')}/api/v4${endpoint}`;
            return await this.helpers.requestOAuth2.call(this, 'gitlabOAuth2Api', options);
        }
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The GitLab credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.message) {
            throw new Error(`Gitlab error response [${error.statusCode}]: ${error.response.body.message}`);
        }
        throw error;
    }
}
exports.gitlabApiRequest = gitlabApiRequest;
//# sourceMappingURL=GenericFunctions.js.map