"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.googleApiRequestAllItems = exports.googleApiRequest = void 0;
async function googleApiRequest(projectId, method, resource, body = {}, qs = {}, headers = {}, uri = null) {
    const options = {
        headers: {
            'Content-Type': 'application/json',
        },
        method,
        body,
        qs,
        url: uri || `https://${projectId}.firebaseio.com/${resource}.json`,
        json: true,
    };
    try {
        if (Object.keys(headers).length !== 0) {
            options.headers = Object.assign({}, options.headers, headers);
        }
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.requestOAuth2.call(this, 'googleFirebaseRealtimeDatabaseOAuth2Api', options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error) {
            let errors;
            if (error.response.body.error.errors) {
                errors = error.response.body.error.errors;
                errors = errors.map((e) => e.message).join('|');
            }
            else {
                errors = error.response.body.error.message;
            }
            throw new Error(`Google Firebase error response [${error.statusCode}]: ${errors}`);
        }
        throw error;
    }
}
exports.googleApiRequest = googleApiRequest;
async function googleApiRequestAllItems(projectId, method, resource, body = {}, qs = {}, headers = {}, uri = null) {
    const returnData = [];
    let responseData;
    qs.pageSize = 100;
    do {
        responseData = await googleApiRequest.call(this, projectId, method, resource, body, qs, {}, uri);
        qs.pageToken = responseData['nextPageToken'];
        returnData.push.apply(returnData, responseData[resource]);
    } while (responseData['nextPageToken'] !== undefined &&
        responseData['nextPageToken'] !== '');
    return returnData;
}
exports.googleApiRequestAllItems = googleApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map