"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractEmail = exports.googleApiRequestAllItems = exports.encodeEmail = exports.parseRawEmail = exports.googleApiRequest = void 0;
const mailparser_1 = require("mailparser");
const mailComposer = require('nodemailer/lib/mail-composer');
async function googleApiRequest(method, endpoint, body = {}, qs = {}, uri, option = {}) {
    let options = {
        headers: {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
        },
        method,
        body,
        qs,
        uri: uri || `https://www.googleapis.com${endpoint}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.requestOAuth2.call(this, 'gmailOAuth2', options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error) {
            let errorMessages;
            if (error.response.body.error.errors) {
                errorMessages = error.response.body.error.errors;
                errorMessages = errorMessages.map((errorItem) => errorItem.message);
                errorMessages = errorMessages.join('|');
            }
            else if (error.response.body.error.message) {
                errorMessages = error.response.body.error.message;
            }
            throw new Error(`Gmail error response [${error.statusCode}]: ${errorMessages}`);
        }
        throw error;
    }
}
exports.googleApiRequest = googleApiRequest;
async function parseRawEmail(messageData, dataPropertyNameDownload) {
    const messageEncoded = Buffer.from(messageData.raw, 'base64').toString('utf8');
    let responseData = await mailparser_1.simpleParser(messageEncoded);
    const headers = {};
    for (const header of responseData.headerLines) {
        headers[header.key] = header.line;
    }
    responseData.headers = headers;
    responseData.headerLines = undefined;
    const binaryData = {};
    if (responseData.attachments) {
        for (let i = 0; i < responseData.attachments.length; i++) {
            const attachment = responseData.attachments[i];
            binaryData[`${dataPropertyNameDownload}${i}`] = await this.helpers.prepareBinaryData(attachment.content, attachment.filename, attachment.contentType);
        }
        responseData.attachments = undefined;
    }
    const mailBaseData = {};
    const resolvedModeAddProperties = [
        'id',
        'threadId',
        'labelIds',
        'sizeEstimate',
    ];
    for (const key of resolvedModeAddProperties) {
        mailBaseData[key] = messageData[key];
    }
    responseData = Object.assign(mailBaseData, responseData);
    return {
        json: responseData,
        binary: Object.keys(binaryData).length ? binaryData : undefined,
    };
}
exports.parseRawEmail = parseRawEmail;
async function encodeEmail(email) {
    let mailBody;
    const mailOptions = {
        to: email.to,
        cc: email.cc,
        bcc: email.bcc,
        replyTo: email.inReplyTo,
        references: email.reference,
        subject: email.subject,
        text: email.body,
    };
    if (email.htmlBody) {
        mailOptions.html = email.htmlBody;
    }
    if (email.attachments !== undefined && Array.isArray(email.attachments) && email.attachments.length > 0) {
        const attachments = email.attachments.map((attachment) => ({
            filename: attachment.name,
            content: attachment.content,
            contentType: attachment.type,
            encoding: 'base64',
        }));
        mailOptions.attachments = attachments;
    }
    const mail = new mailComposer(mailOptions);
    mailBody = await new Promise((resolve) => {
        mail.compile().build(async (err, result) => {
            resolve(result);
        });
    });
    return mailBody.toString('base64').replace(/\+/g, '-').replace(/\//g, '_');
}
exports.encodeEmail = encodeEmail;
async function googleApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.maxResults = 100;
    do {
        responseData = await googleApiRequest.call(this, method, endpoint, body, query);
        query.pageToken = responseData['nextPageToken'];
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData['nextPageToken'] !== undefined &&
        responseData['nextPageToken'] !== '');
    return returnData;
}
exports.googleApiRequestAllItems = googleApiRequestAllItems;
function extractEmail(s) {
    const data = s.split('<')[1];
    return data.substring(0, data.length - 1);
}
exports.extractEmail = extractEmail;
//# sourceMappingURL=GenericFunctions.js.map