"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.contactFields = exports.contactOperations = void 0;
const resource = ['contact'];
exports.contactOperations = [
    {
        displayName: 'Operation',
        name: 'operation',
        type: 'options',
        displayOptions: {
            show: {
                resource,
            },
        },
        options: [
            {
                name: 'Create',
                value: 'create',
                description: `Create a contact`,
            },
            {
                name: 'Delete',
                value: 'delete',
                description: `Delete a contact`,
            },
            {
                name: 'Get',
                value: 'get',
                description: 'Get data of a contact',
            },
            {
                name: 'Get All',
                value: 'getAll',
                description: 'Get data of all contacts',
            },
            {
                name: 'Update',
                value: 'update',
                description: `Update a contact`,
            },
        ],
        default: 'getAll',
        description: 'The operation to perform.',
    },
];
exports.contactFields = [
    {
        displayName: 'Return All',
        name: 'returnAll',
        type: 'boolean',
        displayOptions: {
            show: {
                resource,
                operation: [
                    'getAll',
                ],
            },
        },
        default: false,
        description: 'Returns a list of your user contacts.',
    },
    {
        displayName: 'Limit',
        name: 'limit',
        type: 'number',
        displayOptions: {
            show: {
                resource,
                operation: [
                    'getAll',
                ],
                returnAll: [
                    false,
                ],
            },
        },
        typeOptions: {
            minValue: 1,
            maxValue: 100,
        },
        default: 100,
        description: 'How many results to return.',
    },
    {
        displayName: 'Filters',
        name: 'filters',
        type: 'collection',
        placeholder: 'Add Filter',
        default: {},
        displayOptions: {
            show: {
                resource,
                operation: [
                    'getAll',
                ],
            },
        },
        options: [
            {
                displayName: 'Is Active',
                name: 'is_active',
                type: 'boolean',
                default: true,
                description: 'Pass true to only return active clients and false to return inactive clients.',
            },
            {
                displayName: 'Updated Since',
                name: 'updated_since',
                type: 'dateTime',
                default: '',
                description: 'Only return clients that have been updated since the given date and time.',
            },
        ],
    },
    {
        displayName: 'Contact Id',
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: [
                    'get',
                ],
                resource,
            },
        },
        description: 'The ID of the contact you are retrieving.',
    },
    {
        displayName: 'Contact Id',
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: [
                    'delete',
                ],
                resource,
            },
        },
        description: 'The ID of the contact you want to delete.',
    },
    {
        displayName: 'First Name',
        name: 'firstName',
        type: 'string',
        displayOptions: {
            show: {
                operation: [
                    'create',
                ],
                resource,
            },
        },
        default: '',
        required: true,
        description: 'The first name of the contact.',
    },
    {
        displayName: 'Client Id',
        name: 'clientId',
        type: 'string',
        displayOptions: {
            show: {
                operation: [
                    'create',
                ],
                resource,
            },
        },
        default: '',
        required: true,
        description: 'The ID of the client associated with this contact.',
    },
    {
        displayName: 'Additional Fields',
        name: 'additionalFields',
        type: 'collection',
        placeholder: 'Add Field',
        displayOptions: {
            show: {
                operation: [
                    'create',
                ],
                resource,
            },
        },
        default: {},
        options: [
            {
                displayName: 'Last Name',
                name: 'last_name',
                type: 'string',
                default: '',
                description: 'The last name of the contact.',
            },
            {
                displayName: 'Title',
                name: 'title',
                type: 'string',
                default: '',
                description: 'The title of the contact.',
            },
            {
                displayName: 'Email',
                name: 'email',
                type: 'string',
                default: '',
                description: 'The contact’s email address.',
            },
            {
                displayName: 'Phone Office',
                name: 'phone_office',
                type: 'string',
                default: '',
                description: 'The contact’s office phone number.',
            },
            {
                displayName: 'Phone Mobile',
                name: 'phone_mobile',
                type: 'string',
                default: '',
                description: 'The contact’s mobile phone number.',
            },
            {
                displayName: 'Fax',
                name: 'fax',
                type: 'string',
                default: '',
                description: 'The contact’s fax number.',
            },
        ],
    },
    {
        displayName: 'Contact Id',
        name: 'id',
        type: 'string',
        default: '',
        required: true,
        displayOptions: {
            show: {
                operation: [
                    'update',
                ],
                resource,
            },
        },
        description: 'The ID of the contact want to update.',
    },
    {
        displayName: 'Update Fields',
        name: 'updateFields',
        type: 'collection',
        placeholder: 'Add Field',
        displayOptions: {
            show: {
                operation: [
                    'update',
                ],
                resource,
            },
        },
        default: {},
        options: [
            {
                displayName: 'Client Id',
                name: 'client_id',
                type: 'string',
                default: '',
                description: 'The ID of the client associated with this contact.',
            },
            {
                displayName: 'First Name',
                name: 'first_name',
                type: 'string',
                default: '',
                description: 'The first name of the contact.',
            },
            {
                displayName: 'Last Name',
                name: 'last_name',
                type: 'string',
                default: '',
                description: 'The last name of the contact.',
            },
            {
                displayName: 'Title',
                name: 'title',
                type: 'string',
                default: '',
                description: 'The title of the contact.',
            },
            {
                displayName: 'Email',
                name: 'email',
                type: 'string',
                default: '',
                description: 'The contact’s email address.',
            },
            {
                displayName: 'Phone Office',
                name: 'phone_office',
                type: 'string',
                default: '',
                description: 'The contact’s office phone number.',
            },
            {
                displayName: 'Phone Mobile',
                name: 'phone_mobile',
                type: 'string',
                default: '',
                description: 'The contact’s mobile phone number.',
            },
            {
                displayName: 'Fax',
                name: 'fax',
                type: 'string',
                default: '',
                description: 'The contact’s fax number.',
            },
        ],
    },
];
//# sourceMappingURL=ContactDescription.js.map