"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.helpscoutApiRequestAllItems = exports.helpscoutApiRequest = void 0;
const lodash_1 = require("lodash");
async function helpscoutApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    let options = {
        headers: {
            'Content-Type': 'application/json',
        },
        method,
        body,
        qs,
        uri: uri || `https://api.helpscout.net${resource}`,
        json: true,
    };
    try {
        if (Object.keys(option).length !== 0) {
            options = Object.assign({}, options, option);
        }
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await this.helpers.requestOAuth2.call(this, 'helpScoutOAuth2Api', options);
    }
    catch (error) {
        if (error.response && error.response.body
            && error.response.body._embedded
            && error.response.body._embedded.errors) {
            throw new Error(`HelpScout error response [${error.statusCode}]: ${error.response.body.message} - ${error.response.body._embedded.errors.map(error => {
                return `${error.path} ${error.message}`;
            }).join('-')}`);
        }
        throw new Error(`HelpScout error response [${error.statusCode}]: ${error.message}`);
    }
}
exports.helpscoutApiRequest = helpscoutApiRequest;
async function helpscoutApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    let uri;
    do {
        responseData = await helpscoutApiRequest.call(this, method, endpoint, body, query, uri);
        uri = lodash_1.get(responseData, '_links.next.href');
        returnData.push.apply(returnData, lodash_1.get(responseData, propertyName));
        if (query.limit && query.limit <= returnData.length) {
            return returnData;
        }
    } while (responseData['_links'] !== undefined &&
        responseData['_links'].next !== undefined &&
        responseData['_links'].next.href !== undefined);
    return returnData;
}
exports.helpscoutApiRequestAllItems = helpscoutApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map