"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.humanticAiApiRequest = void 0;
async function humanticAiApiRequest(method, resource, body = {}, qs = {}, option = {}) {
    try {
        const credentials = this.getCredentials('humanticAiApi');
        if (credentials === undefined) {
            throw new Error('No credentials got returned!');
        }
        let options = {
            headers: {
                'Content-Type': 'application/json',
            },
            method,
            qs,
            body,
            uri: `https://api.humantic.ai/v1${resource}`,
            json: true,
        };
        options = Object.assign({}, options, option);
        options.qs.apikey = credentials.apiKey;
        if (Object.keys(options.body).length === 0) {
            delete options.body;
        }
        const response = await this.helpers.request(options);
        if (response.data && response.data.status === 'error') {
            throw new Error(`Humantic AI error response [400]: ${response.data.message}`);
        }
        return response;
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.message) {
            const errorBody = error.response.body;
            throw new Error(`Humantic AI error response [${error.statusCode}]: ${errorBody.message}`);
        }
        throw error;
    }
}
exports.humanticAiApiRequest = humanticAiApiRequest;
//# sourceMappingURL=GenericFunctions.js.map