"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MailerLite = void 0;
const GenericFunctions_1 = require("./GenericFunctions");
const SubscriberDescription_1 = require("./SubscriberDescription");
class MailerLite {
    constructor() {
        this.description = {
            displayName: 'MailerLite',
            name: 'mailerLite',
            icon: 'file:mailerLite.png',
            group: ['input'],
            version: 1,
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            description: 'Consume Mailer Lite API.',
            defaults: {
                name: 'MailerLite',
                color: '#58be72',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'mailerLiteApi',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    options: [
                        {
                            name: 'Subscriber',
                            value: 'subscriber',
                        },
                    ],
                    default: 'subscriber',
                    description: 'The resource to operate on.',
                },
                ...SubscriberDescription_1.subscriberOperations,
                ...SubscriberDescription_1.subscriberFields,
            ],
        };
        this.methods = {
            loadOptions: {
                async getCustomFields() {
                    const returnData = [];
                    const fields = await GenericFunctions_1.mailerliteApiRequest.call(this, 'GET', '/fields');
                    for (const field of fields) {
                        returnData.push({
                            name: field.key,
                            value: field.key,
                        });
                    }
                    return returnData;
                },
            },
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        const length = items.length;
        const qs = {};
        let responseData;
        const resource = this.getNodeParameter('resource', 0);
        const operation = this.getNodeParameter('operation', 0);
        for (let i = 0; i < length; i++) {
            if (resource === 'subscriber') {
                if (operation === 'create') {
                    const email = this.getNodeParameter('email', i);
                    const additionalFields = this.getNodeParameter('additionalFields', i);
                    const body = {
                        email,
                        fields: [],
                    };
                    Object.assign(body, additionalFields);
                    if (additionalFields.customFieldsUi) {
                        const customFieldsValues = additionalFields.customFieldsUi.customFieldsValues;
                        if (customFieldsValues) {
                            const fields = {};
                            for (const customFieldValue of customFieldsValues) {
                                fields[customFieldValue.fieldId] = customFieldValue.value;
                            }
                            body.fields = fields;
                            delete body.customFieldsUi;
                        }
                    }
                    responseData = await GenericFunctions_1.mailerliteApiRequest.call(this, 'POST', '/subscribers', body);
                }
                if (operation === 'get') {
                    const subscriberId = this.getNodeParameter('subscriberId', i);
                    responseData = await GenericFunctions_1.mailerliteApiRequest.call(this, 'GET', `/subscribers/${subscriberId}`);
                }
                if (operation === 'getAll') {
                    const returnAll = this.getNodeParameter('returnAll', i);
                    const filters = this.getNodeParameter('filters', i);
                    Object.assign(qs, filters);
                    if (returnAll) {
                        responseData = await GenericFunctions_1.mailerliteApiRequestAllItems.call(this, 'GET', `/subscribers`, {}, qs);
                    }
                    else {
                        qs.limit = this.getNodeParameter('limit', i);
                        responseData = await GenericFunctions_1.mailerliteApiRequest.call(this, 'GET', `/subscribers`, {}, qs);
                    }
                }
                if (operation === 'update') {
                    const subscriberId = this.getNodeParameter('subscriberId', i);
                    const updateFields = this.getNodeParameter('updateFields', i);
                    const body = {};
                    Object.assign(body, updateFields);
                    if (updateFields.customFieldsUi) {
                        const customFieldsValues = updateFields.customFieldsUi.customFieldsValues;
                        if (customFieldsValues) {
                            const fields = {};
                            for (const customFieldValue of customFieldsValues) {
                                fields[customFieldValue.fieldId] = customFieldValue.value;
                            }
                            body.fields = fields;
                            delete body.customFieldsUi;
                        }
                    }
                    responseData = await GenericFunctions_1.mailerliteApiRequest.call(this, 'PUT', `/subscribers/${subscriberId}`, body);
                }
            }
        }
        if (Array.isArray(responseData)) {
            returnData.push.apply(returnData, responseData);
        }
        else if (responseData !== undefined) {
            returnData.push(responseData);
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.MailerLite = MailerLite;
//# sourceMappingURL=MailerLite.node.js.map