"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.apiRequestAllItems = exports.apiRequest = void 0;
async function apiRequest(method, endpoint, body, query) {
    const credentials = this.getCredentials('mattermostApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    query = query || {};
    const options = {
        method,
        body,
        qs: query,
        uri: `${credentials.baseUrl}/api/v4/${endpoint}`,
        headers: {
            Authorization: `Bearer ${credentials.accessToken}`,
            'content-type': 'application/json; charset=utf-8',
        },
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Mattermost credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.message) {
            const errorBody = error.response.body;
            throw new Error(`Mattermost error response: ${errorBody.message}`);
        }
        throw error;
    }
}
exports.apiRequest = apiRequest;
async function apiRequestAllItems(method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.page = 0;
    query.per_page = 100;
    do {
        responseData = await apiRequest.call(this, method, endpoint, body, query);
        query.page++;
        returnData.push.apply(returnData, responseData);
    } while (responseData.length !== 0);
    return returnData;
}
exports.apiRequestAllItems = apiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map