"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.moceanApiRequest = void 0;
async function moceanApiRequest(method, endpoint, body, query) {
    const credentials = this.getCredentials('moceanApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    if (query === undefined) {
        query = {};
    }
    if (method === 'POST') {
        body['mocean-api-key'] = credentials['mocean-api-key'];
        body['mocean-api-secret'] = credentials['mocean-api-secret'];
        body['mocean-resp-format'] = 'JSON';
    }
    else if (method === 'GET') {
        query['mocean-api-key'] = credentials['mocean-api-key'];
        query['mocean-api-secret'] = credentials['mocean-api-secret'];
        query['mocean-resp-format'] = 'JSON';
    }
    const options = {
        method,
        form: body,
        qs: query,
        uri: `https://rest.moceanapi.com${endpoint}`,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('Authentication failed.');
        }
        if (error.response && error.response.body && error.response.body.message) {
            let errorMessage = error.response.body.message;
            if (error.response.body.more_info) {
                errorMessage += `errorMessage (${error.response.body.more_info})`;
            }
            throw new Error(`Mocean error response [${error.statusCode}]: ${errorMessage}`);
        }
        throw error;
    }
}
exports.moceanApiRequest = moceanApiRequest;
//# sourceMappingURL=GenericFunctions.js.map