"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.paddleApiRequestAllItems = exports.paddleApiRequest = void 0;
async function paddleApiRequest(endpoint, method, body = {}, query, uri) {
    const credentials = this.getCredentials('paddleApi');
    if (credentials === undefined) {
        throw new Error('Could not retrieve credentials!');
    }
    const options = {
        method,
        headers: {
            'content-type': 'application/json',
        },
        uri: `https://vendors.paddle.com/api${endpoint}`,
        body,
        json: true,
    };
    body['vendor_id'] = credentials.vendorId;
    body['vendor_auth_code'] = credentials.vendorAuthCode;
    try {
        const response = await this.helpers.request(options);
        if (!response.success) {
            throw new Error(`Code: ${response.error.code}. Message: ${response.error.message}`);
        }
        return response;
    }
    catch (error) {
        throw new Error(`ERROR: Code: ${error.code}. Message: ${error.message}`);
    }
}
exports.paddleApiRequest = paddleApiRequest;
async function paddleApiRequestAllItems(propertyName, endpoint, method, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    body.results_per_page = 200;
    body.page = 1;
    do {
        responseData = await paddleApiRequest.call(this, endpoint, method, body, query);
        returnData.push.apply(returnData, responseData[propertyName]);
        body.page++;
    } while (responseData[propertyName].length !== 0 && responseData[propertyName].length === body.results_per_page);
    return returnData;
}
exports.paddleApiRequestAllItems = paddleApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = undefined;
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map