"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.upperFist = exports.validateJSON = exports.payPalApiRequestAllItems = exports.payPalApiRequest = void 0;
const n8n_core_1 = require("n8n-core");
async function payPalApiRequest(endpoint, method, body = {}, query, uri) {
    const credentials = this.getCredentials('payPalApi');
    const env = getEnvironment(credentials.env);
    const tokenInfo = await getAccessToken.call(this);
    const headerWithAuthentication = Object.assign({}, { Authorization: `Bearer ${tokenInfo.access_token}`, 'Content-Type': 'application/json' });
    const options = {
        headers: headerWithAuthentication,
        method,
        qs: query || {},
        uri: uri || `${env}/v1${endpoint}`,
        body,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.response.body) {
            let errorMessage = error.response.body.message;
            if (error.response.body.details) {
                errorMessage += ` - Details: ${JSON.stringify(error.response.body.details)}`;
            }
            throw new Error(errorMessage);
        }
        throw error;
    }
}
exports.payPalApiRequest = payPalApiRequest;
function getEnvironment(env) {
    return {
        'sanbox': 'https://api.sandbox.paypal.com',
        'live': 'https://api.paypal.com',
    }[env];
}
async function getAccessToken() {
    const credentials = this.getCredentials('payPalApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const env = getEnvironment(credentials.env);
    const data = Buffer.from(`${credentials.clientId}:${credentials.secret}`).toString(n8n_core_1.BINARY_ENCODING);
    const headerWithAuthentication = Object.assign({}, { Authorization: `Basic ${data}`, 'Content-Type': 'application/x-www-form-urlencoded' });
    const options = {
        headers: headerWithAuthentication,
        method: 'POST',
        form: {
            grant_type: 'client_credentials',
        },
        uri: `${env}/v1/oauth2/token`,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        const errorMessage = error.response.body.message || error.response.body.Message;
        if (errorMessage !== undefined) {
            throw new Error(errorMessage);
        }
        throw new Error(error.response.body);
    }
}
async function payPalApiRequestAllItems(propertyName, endpoint, method, body = {}, query, uri) {
    const returnData = [];
    let responseData;
    query.page_size = 1000;
    do {
        responseData = await payPalApiRequest.call(this, endpoint, method, body, query, uri);
        uri = getNext(responseData.links);
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (getNext(responseData.links) !== undefined);
    return returnData;
}
exports.payPalApiRequestAllItems = payPalApiRequestAllItems;
function getNext(links) {
    for (const link of links) {
        if (link.rel === 'next') {
            return link.href;
        }
    }
    return undefined;
}
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = '';
    }
    return result;
}
exports.validateJSON = validateJSON;
function upperFist(s) {
    return s.split('.').map(e => {
        return e.toLowerCase().charAt(0).toUpperCase() + e.toLowerCase().slice(1);
    }).join(' ');
}
exports.upperFist = upperFist;
//# sourceMappingURL=GenericFunctions.js.map