"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.eventExists = exports.convertTriggerObjectToStringArray = exports.postmarkApiRequest = void 0;
async function postmarkApiRequest(method, endpoint, body = {}, option = {}) {
    const credentials = this.getCredentials('postmarkApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    let options = {
        headers: {
            'Content-Type': 'application/json',
            'Accept': 'application/json',
            'X-Postmark-Server-Token': credentials.serverToken,
        },
        method,
        body,
        uri: 'https://api.postmarkapp.com' + endpoint,
        json: true,
    };
    if (body === {}) {
        delete options.body;
    }
    options = Object.assign({}, options, option);
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        throw new Error(`Postmark: ${error.statusCode} Message: ${error.message}`);
    }
}
exports.postmarkApiRequest = postmarkApiRequest;
function convertTriggerObjectToStringArray(webhookObject) {
    const triggers = webhookObject.Triggers;
    const webhookEvents = [];
    if (triggers.Open.Enabled) {
        webhookEvents.push('open');
    }
    if (triggers.Open.PostFirstOpenOnly) {
        webhookEvents.push('firstOpen');
    }
    if (triggers.Click.Enabled) {
        webhookEvents.push('click');
    }
    if (triggers.Delivery.Enabled) {
        webhookEvents.push('delivery');
    }
    if (triggers.Bounce.Enabled) {
        webhookEvents.push('bounce');
    }
    if (triggers.Bounce.IncludeContent) {
        webhookEvents.push('includeContent');
    }
    if (triggers.SpamComplaint.Enabled) {
        webhookEvents.push('spamComplaint');
    }
    if (triggers.SpamComplaint.IncludeContent) {
        if (!webhookEvents.includes('IncludeContent')) {
            webhookEvents.push('includeContent');
        }
    }
    if (triggers.SubscriptionChange.Enabled) {
        webhookEvents.push('subscriptionChange');
    }
    return webhookEvents;
}
exports.convertTriggerObjectToStringArray = convertTriggerObjectToStringArray;
function eventExists(currentEvents, webhookEvents) {
    for (const currentEvent of currentEvents) {
        if (!webhookEvents.includes(currentEvent)) {
            return false;
        }
    }
    return true;
}
exports.eventExists = eventExists;
//# sourceMappingURL=GenericFunctions.js.map