"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pushbulletApiRequestAllItems = exports.pushbulletApiRequest = void 0;
async function pushbulletApiRequest(method, path, body = {}, qs = {}, uri, option = {}) {
    const options = {
        method,
        body,
        qs,
        uri: uri || `https://api.pushbullet.com/v2${path}`,
        json: true,
    };
    try {
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        if (Object.keys(option).length !== 0) {
            Object.assign(options, option);
        }
        return await this.helpers.requestOAuth2.call(this, 'pushbulletOAuth2Api', options);
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.error) {
            const message = error.response.body.error.message;
            throw new Error(`Pushbullet error response [${error.statusCode}]: ${message}`);
        }
        throw error;
    }
}
exports.pushbulletApiRequest = pushbulletApiRequest;
async function pushbulletApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    do {
        responseData = await pushbulletApiRequest.call(this, method, endpoint, body, query);
        returnData.push.apply(returnData, responseData[propertyName]);
    } while (responseData.cursor !== undefined);
    return returnData;
}
exports.pushbulletApiRequestAllItems = pushbulletApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map