"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.quickbaseApiRequestAllItems = exports.getFieldsObject = exports.quickbaseApiRequest = void 0;
async function quickbaseApiRequest(method, resource, body = {}, qs = {}, option = {}) {
    var _a;
    const credentials = this.getCredentials('quickbaseApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    if (!credentials.hostname) {
        throw new Error('Hostname must be defined');
    }
    if (!credentials.userToken) {
        throw new Error('User Token must be defined');
    }
    try {
        const options = {
            headers: {
                'QB-Realm-Hostname': credentials.hostname,
                'User-Agent': 'n8n',
                'Authorization': `QB-USER-TOKEN ${credentials.userToken}`,
                'Content-Type': 'application/json',
            },
            method,
            body,
            qs,
            uri: `https://api.quickbase.com/v1${resource}`,
            json: true,
        };
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        if (Object.keys(qs).length === 0) {
            delete options.qs;
        }
        if (Object.keys(option).length !== 0) {
            Object.assign(options, option);
        }
        return await ((_a = this.helpers) === null || _a === void 0 ? void 0 : _a.request(options));
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.description) {
            const message = error.response.body.description;
            throw new Error(`Quickbase error response [${error.statusCode}]: ${message} (qb-api-ray=${error.response.headers['qb-api-ray']})`);
        }
        throw error;
    }
}
exports.quickbaseApiRequest = quickbaseApiRequest;
async function getFieldsObject(tableId) {
    const fieldsLabelKey = {};
    const fieldsIdKey = {};
    const data = await quickbaseApiRequest.call(this, 'GET', '/fields', {}, { tableId });
    for (const field of data) {
        fieldsLabelKey[field.label] = field.id;
        fieldsIdKey[field.id] = field.label;
    }
    return { fieldsLabelKey, fieldsIdKey };
}
exports.getFieldsObject = getFieldsObject;
async function quickbaseApiRequestAllItems(method, resource, body = {}, query = {}) {
    const returnData = [];
    let responseData = [];
    if (method === 'POST') {
        body.options = {
            skip: 0,
            top: 100,
        };
    }
    else {
        query.skip = 0;
        query.top = 100;
    }
    let metadata;
    do {
        const { data, fields, metadata: meta } = await quickbaseApiRequest.call(this, method, resource, body, query);
        metadata = meta;
        const fieldsIdKey = {};
        for (const field of fields) {
            fieldsIdKey[field.id] = field.label;
        }
        for (const record of data) {
            const data = {};
            for (const [key, value] of Object.entries(record)) {
                data[fieldsIdKey[key]] = value.value;
            }
            responseData.push(data);
        }
        if (method === 'POST') {
            body.options.skip += body.options.top;
        }
        else {
            query.skip += query.top;
        }
        returnData.push.apply(returnData, responseData);
        responseData = [];
    } while (returnData.length < metadata.totalRecords);
    return returnData;
}
exports.quickbaseApiRequestAllItems = quickbaseApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map