"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.s3ApiRequestSOAPAllItems = exports.s3ApiRequestSOAP = exports.s3ApiRequestREST = exports.s3ApiRequest = void 0;
const aws4_1 = require("aws4");
const lodash_1 = require("lodash");
const xml2js_1 = require("xml2js");
const url_1 = require("url");
async function s3ApiRequest(bucket, method, path, body, query = {}, headers, option = {}, region) {
    var _a, _b;
    let credentials;
    credentials = this.getCredentials('s3');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    if (!credentials.endpoint.startsWith('http')) {
        throw new Error('HTTP(S) Scheme is required in endpoint definition');
    }
    const endpoint = new url_1.URL(credentials.endpoint);
    if (bucket) {
        if (credentials.forcePathStyle) {
            path = `/${bucket}${path}`;
        }
        else {
            endpoint.host = `${bucket}.${endpoint.host}`;
        }
    }
    endpoint.pathname = path;
    const signOpts = {
        headers: headers || {},
        region: region || credentials.region,
        host: endpoint.host,
        method,
        path: `${path}?${queryToString(query).replace(/\+/g, '%2B')}`,
        service: 's3',
        body,
    };
    aws4_1.sign(signOpts, { accessKeyId: `${credentials.accessKeyId}`.trim(), secretAccessKey: `${credentials.secretAccessKey}`.trim() });
    const options = {
        headers: signOpts.headers,
        method,
        qs: query,
        uri: endpoint.toString(),
        body: signOpts.body,
    };
    if (Object.keys(option).length !== 0) {
        Object.assign(options, option);
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        const errorMessage = ((_a = error.response) === null || _a === void 0 ? void 0 : _a.body.message) || ((_b = error.response) === null || _b === void 0 ? void 0 : _b.body.Message) || error.message;
        if (error.statusCode === 403) {
            if (errorMessage === 'The security token included in the request is invalid.') {
                throw new Error('The S3 credentials are not valid!');
            }
            else if (errorMessage.startsWith('The request signature we calculated does not match the signature you provided')) {
                throw new Error('The S3 credentials are not valid!');
            }
        }
        throw new Error(`S3 error response [${error.statusCode}]: ${errorMessage}`);
    }
}
exports.s3ApiRequest = s3ApiRequest;
async function s3ApiRequestREST(bucket, method, path, body, query = {}, headers, options = {}, region) {
    const response = await s3ApiRequest.call(this, bucket, method, path, body, query, headers, options, region);
    try {
        return JSON.parse(response);
    }
    catch (e) {
        return response;
    }
}
exports.s3ApiRequestREST = s3ApiRequestREST;
async function s3ApiRequestSOAP(bucket, method, path, body, query = {}, headers, option = {}, region) {
    const response = await s3ApiRequest.call(this, bucket, method, path, body, query, headers, option, region);
    try {
        return await new Promise((resolve, reject) => {
            xml2js_1.parseString(response, { explicitArray: false }, (err, data) => {
                if (err) {
                    return reject(err);
                }
                resolve(data);
            });
        });
    }
    catch (e) {
        return e;
    }
}
exports.s3ApiRequestSOAP = s3ApiRequestSOAP;
async function s3ApiRequestSOAPAllItems(propertyName, service, method, path, body, query = {}, headers = {}, option = {}, region) {
    const returnData = [];
    let responseData;
    do {
        responseData = await s3ApiRequestSOAP.call(this, service, method, path, body, query, headers, option, region);
        if (lodash_1.get(responseData, `${propertyName.split('.')[0]}.NextContinuationToken`)) {
            query['continuation-token'] = lodash_1.get(responseData, `${propertyName.split('.')[0]}.NextContinuationToken`);
        }
        if (lodash_1.get(responseData, propertyName)) {
            if (Array.isArray(lodash_1.get(responseData, propertyName))) {
                returnData.push.apply(returnData, lodash_1.get(responseData, propertyName));
            }
            else {
                returnData.push(lodash_1.get(responseData, propertyName));
            }
        }
        if (query.limit && query.limit <= returnData.length) {
            return returnData;
        }
    } while (lodash_1.get(responseData, `${propertyName.split('.')[0]}.IsTruncated`) !== undefined &&
        lodash_1.get(responseData, `${propertyName.split('.')[0]}.IsTruncated`) !== 'false');
    return returnData;
}
exports.s3ApiRequestSOAPAllItems = s3ApiRequestSOAPAllItems;
function queryToString(params) {
    return Object.keys(params).map(key => key + '=' + params[key]).join('&');
}
//# sourceMappingURL=GenericFunctions.js.map