"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.strapiApiRequestAllItems = exports.getToken = exports.strapiApiRequest = void 0;
async function strapiApiRequest(method, resource, body = {}, qs = {}, uri, headers = {}) {
    var _a;
    const credentials = this.getCredentials('strapiApi');
    try {
        const options = {
            headers: {},
            method,
            body,
            qs,
            uri: uri || `${credentials.url}${resource}`,
            json: true,
        };
        if (Object.keys(headers).length !== 0) {
            options.headers = Object.assign({}, options.headers, headers);
        }
        if (Object.keys(body).length === 0) {
            delete options.body;
        }
        return await ((_a = this.helpers) === null || _a === void 0 ? void 0 : _a.request(options));
    }
    catch (error) {
        if (error.response && error.response.body && error.response.body.message) {
            let messages = error.response.body.message;
            if (Array.isArray(error.response.body.message)) {
                messages = messages[0].messages.map((e) => e.message).join('|');
            }
            throw new Error(`Strapi error response [${error.statusCode}]: ${messages}`);
        }
        throw error;
    }
}
exports.strapiApiRequest = strapiApiRequest;
async function getToken() {
    const credentials = this.getCredentials('strapiApi');
    const options = {
        headers: {
            'content-type': `application/json`,
        },
        method: 'POST',
        uri: `${credentials.url}/auth/local`,
        body: {
            identifier: credentials.email,
            password: credentials.password,
        },
        json: true,
    };
    return this.helpers.request(options);
}
exports.getToken = getToken;
async function strapiApiRequestAllItems(method, resource, body = {}, query = {}, headers = {}) {
    const returnData = [];
    let responseData;
    query._limit = 20;
    query._start = 0;
    do {
        responseData = await strapiApiRequest.call(this, method, resource, body, query, undefined, headers);
        query._start += query._limit;
        returnData.push.apply(returnData, responseData);
    } while (responseData.length !== 0);
    return returnData;
}
exports.strapiApiRequestAllItems = strapiApiRequestAllItems;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = undefined;
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map