"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.stripeApiRequest = void 0;
async function stripeApiRequest(method, endpoint, body, query) {
    const credentials = this.getCredentials('stripeApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const options = {
        method,
        auth: {
            user: credentials.secretKey,
        },
        form: body,
        qs: query,
        uri: `https://api.stripe.com/v1${endpoint}`,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Stripe credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.message) {
            throw new Error(`Stripe error response [${error.statusCode}]: ${error.response.body.message}`);
        }
        throw error;
    }
}
exports.stripeApiRequest = stripeApiRequest;
//# sourceMappingURL=helpers.js.map