"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.uprocApiRequest = void 0;
async function uprocApiRequest(method, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('uprocApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const token = Buffer.from(`${credentials.email}:${credentials.apiKey}`).toString('base64');
    const options = {
        headers: { Authorization: `Basic ${token}` },
        method,
        qs,
        body,
        uri: uri || `https://api.uproc.io/api/v2/process`,
        json: true,
    };
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.statusCode === 403) {
            throw new Error('The uProc credentials are not valid!');
        }
        if (error.response.body && error.response.body.error && error.response.body.error.message) {
            throw new Error(`uProc Error [${error.statusCode}]: ${error.response.body.error.message}`);
        }
        throw new Error('uProc Error: ' + error.message);
    }
}
exports.uprocApiRequest = uprocApiRequest;
//# sourceMappingURL=GenericFunctions.js.map