"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UProc = void 0;
const GenericFunctions_1 = require("./GenericFunctions");
const GroupDescription_1 = require("./GroupDescription");
const ToolDescription_1 = require("./ToolDescription");
class UProc {
    constructor() {
        this.description = {
            displayName: 'uProc',
            name: 'uproc',
            icon: 'file:uproc.png',
            group: ['output'],
            version: 1,
            subtitle: '={{$parameter["tool"]}}',
            description: 'Consume uProc API',
            defaults: {
                name: 'uProc',
                color: '#219ef9',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'uprocApi',
                    required: true,
                },
            ],
            properties: [
                ...GroupDescription_1.groupOptions,
                ...ToolDescription_1.toolOperations,
                ...ToolDescription_1.toolParameters,
                {
                    displayName: 'Additional Options',
                    name: 'additionalOptions',
                    type: 'collection',
                    placeholder: 'Add Option',
                    default: {},
                    displayOptions: {
                        show: {
                            group: [
                                'audio',
                                'communication',
                                'company',
                                'finance',
                                'geographic',
                                'image',
                                'internet',
                                'personal',
                                'product',
                                'security',
                                'text',
                            ],
                        },
                    },
                    options: [
                        {
                            displayName: 'Data Webhook',
                            name: 'dataWebhook',
                            type: 'string',
                            description: 'URL to send tool response when tool has resolved your request. You can create your own webhook at <a href="https://beeceptor.com" target="_blank">Beeceptor</a>, <a href="https://www.integromat.com/" target="_blank">Integromat</a>, <a href="https://zapier.com/" target="_blank">Zapier</a> or <a href="https://n8n.io/" target="_blank">n8n</a>',
                            default: '',
                        },
                    ],
                },
            ],
        };
    }
    async execute() {
        const items = this.getInputData();
        const returnData = [];
        const length = items.length;
        let responseData;
        const group = this.getNodeParameter('group', 0);
        const tool = this.getNodeParameter('tool', 0);
        const additionalOptions = this.getNodeParameter('additionalOptions', 0);
        const dataWebhook = additionalOptions.dataWebhook;
        const fields = ToolDescription_1.toolParameters.filter((field) => {
            return field && field.displayOptions && field.displayOptions.show && field.displayOptions.show.group && field.displayOptions.show.tool &&
                field.displayOptions.show.group.indexOf(group) !== -1 && field.displayOptions.show.tool.indexOf(tool) !== -1;
        }).map((field) => {
            return field.name;
        });
        const requestPromises = [];
        for (let i = 0; i < length; i++) {
            const toolKey = tool.replace(/([A-Z]+)/g, '-$1').toLowerCase();
            const body = {
                processor: toolKey,
                params: {},
            };
            fields.forEach((field) => {
                if (field && field.length) {
                    const data = this.getNodeParameter(field, i);
                    body.params[field] = data + '';
                }
            });
            if (dataWebhook && dataWebhook.length) {
                body.callback = {};
            }
            if (dataWebhook && dataWebhook.length) {
                body.callback.data = dataWebhook;
            }
            responseData = await GenericFunctions_1.uprocApiRequest.call(this, 'POST', body);
            if (Array.isArray(responseData)) {
                returnData.push.apply(returnData, responseData);
            }
            else {
                returnData.push(responseData);
            }
        }
        return [this.helpers.returnJsonArray(returnData)];
    }
}
exports.UProc = UProc;
//# sourceMappingURL=UProc.node.js.map