"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.wordpressApiRequestAllItems = exports.wordpressApiRequest = void 0;
async function wordpressApiRequest(method, resource, body = {}, qs = {}, uri, option = {}) {
    const credentials = this.getCredentials('wordpressApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    let options = {
        headers: {
            Accept: 'application/json',
            'Content-Type': 'application/json',
        },
        auth: {
            user: credentials.username,
            password: credentials.password,
        },
        method,
        qs,
        body,
        uri: uri || `${credentials.url}/wp-json/wp/v2${resource}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(options.body).length === 0) {
        delete options.body;
    }
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        let errorMessage = error.message;
        if (error.response && error.response.body) {
            errorMessage = error.response.body.message || error.response.body.Message || error.message;
        }
        throw new Error('Wordpress Error: ' + errorMessage);
    }
}
exports.wordpressApiRequest = wordpressApiRequest;
async function wordpressApiRequestAllItems(method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.per_page = 10;
    query.page = 0;
    do {
        query.page++;
        responseData = await wordpressApiRequest.call(this, method, endpoint, body, query, undefined, { resolveWithFullResponse: true });
        returnData.push.apply(returnData, responseData.body);
    } while (responseData.headers['x-wp-totalpages'] !== undefined &&
        parseInt(responseData.headers['x-wp-totalpages'], 10) < query.page);
    return returnData;
}
exports.wordpressApiRequestAllItems = wordpressApiRequestAllItems;
//# sourceMappingURL=GenericFunctions.js.map