"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.zoomApiRequestAllItems = exports.zoomApiRequest = void 0;
async function zoomApiRequest(method, resource, body = {}, query = {}, headers = undefined, option = {}) {
    const authenticationMethod = this.getNodeParameter('authentication', 0, 'accessToken');
    let options = {
        method,
        headers: headers || {
            'Content-Type': 'application/json',
        },
        body,
        qs: query,
        uri: `https://api.zoom.us/v2${resource}`,
        json: true,
    };
    options = Object.assign({}, options, option);
    if (Object.keys(body).length === 0) {
        delete options.body;
    }
    if (Object.keys(query).length === 0) {
        delete options.qs;
    }
    try {
        if (authenticationMethod === 'accessToken') {
            const credentials = this.getCredentials('zoomApi');
            if (credentials === undefined) {
                throw new Error('No credentials got returned!');
            }
            options.headers.Authorization = `Bearer ${credentials.accessToken}`;
            return await this.helpers.request(options);
        }
        else {
            return await this.helpers.requestOAuth2.call(this, 'zoomOAuth2Api', options);
        }
    }
    catch (error) {
        if (error.statusCode === 401) {
            throw new Error('The Zoom credentials are not valid!');
        }
        if (error.response && error.response.body && error.response.body.message) {
            throw new Error(`Zoom error response [${error.statusCode}]: ${error.response.body.message}`);
        }
        throw error;
    }
}
exports.zoomApiRequest = zoomApiRequest;
async function zoomApiRequestAllItems(propertyName, method, endpoint, body = {}, query = {}) {
    const returnData = [];
    let responseData;
    query.page_number = 0;
    do {
        responseData = await zoomApiRequest.call(this, method, endpoint, body, query);
        query.page_number++;
        returnData.push.apply(returnData, responseData[propertyName]);
        await wait();
    } while (responseData.page_count !== responseData.page_number);
    return returnData;
}
exports.zoomApiRequestAllItems = zoomApiRequestAllItems;
function wait() {
    return new Promise((resolve, reject) => {
        setTimeout(() => {
            resolve(true);
        }, 1000);
    });
}
//# sourceMappingURL=GenericFunctions.js.map