"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateJSON = exports.zulipApiRequest = void 0;
async function zulipApiRequest(method, resource, body = {}, query = {}, uri, option = {}) {
    const credentials = this.getCredentials('zulipApi');
    if (credentials === undefined) {
        throw new Error('No credentials got returned!');
    }
    const endpoint = `${credentials.url}/api/v1`;
    let options = {
        auth: {
            user: credentials.email,
            password: credentials.apiKey,
        },
        headers: {
            'Content-Type': 'application/x-www-form-urlencoded',
        },
        method,
        form: body,
        qs: query,
        uri: uri || `${endpoint}${resource}`,
        json: true,
    };
    if (!Object.keys(body).length) {
        delete options.form;
    }
    if (!Object.keys(query).length) {
        delete options.qs;
    }
    options = Object.assign({}, options, option);
    try {
        return await this.helpers.request(options);
    }
    catch (error) {
        if (error.response) {
            const errorMessage = error.response.body.message || error.response.body.description || error.message;
            throw new Error(`Zulip error response [${error.statusCode}]: ${errorMessage}`);
        }
        throw error;
    }
}
exports.zulipApiRequest = zulipApiRequest;
function validateJSON(json) {
    let result;
    try {
        result = JSON.parse(json);
    }
    catch (exception) {
        result = undefined;
    }
    return result;
}
exports.validateJSON = validateJSON;
//# sourceMappingURL=GenericFunctions.js.map